@@ -4,7 +4,6 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 593.6 KB.
 #'
-#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
 #'
 #' @format \code{sf} data frame with 142 rows of 4 variables + geometry
 #'
@@ -20,7 +19,7 @@
 #'
 #' @export
 
-casti <- function(method = "curl") {
+casti <- function() {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -42,7 +41,7 @@ casti <- function(method = "curl") {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
+      curl_download(url = remote_file, destfile = local_file, quiet = T)
     }
   }
 
