@@ -4,8 +4,6 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 118.6 KB.
 #'
-#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
-#'
 #' @format \code{sf} data frame with 480 rows of 5 variables + geometry
 #'
 #' \describe{
@@ -21,7 +19,7 @@
 #'
 #' @export
 
-plochy <- function(method = "curl") {
+plochy <- function() {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -43,8 +41,9 @@ plochy <- function(method = "curl") {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
-    }
+      curl_download(url = remote_file, destfile = local_file, quiet = T)
+
+      }
   }
 
   local_df <- readRDS(local_file)
